/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2019  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#ifndef PCDMONITORREMOTEHEADERFILE
#define PCDMONITORREMOTEHEADERFILE

#include <QMainWindow>
#include <QAbstractSocket>

class QSettings;
class QToolButton;
class QSlider;
class QLineEdit;
class QCloseEvent;
class QTcpSocket;
class QKeyEvent;
class QLabel;
class TDisplayWidget;
class TIPWidget;

class TPCDMonitorRemote : public QMainWindow
{
Q_OBJECT

public:

// CREATORS
	TPCDMonitorRemote(const QWidget *parent=0, Qt::WindowFlags flags=0);
	virtual ~TPCDMonitorRemote(void);

// ACCESSORS

// MANIPULATORS

signals:

private slots:
	void Update_Font(int);
	void Connect_Disconnect(void);
	void Connected(void);
	void Data_Ready(void);
	void Data_Error(QAbstractSocket::SocketError);
	
protected:
	virtual void closeEvent(QCloseEvent *event);
	virtual void keyReleaseEvent(QKeyEvent *event);

private:
	
enum TConnectionStatus
{
	NO_CONNECTION = 0,
	CONNECTING,
	CONNECTED
};
	
	QSettings							*d_settings;
	TDisplayWidget						*d_display_widget;
	QLabel								*d_status_text;
	QToolButton							*d_power_button;
	QSlider								*d_font_slider;
	QWidget								*d_toolbar;
	QTcpSocket							*d_tcp_socket;
	TIPWidget							*d_ip_widget;
	TConnectionStatus					d_connection_status;
	
	bool								d_receiving_status;
	
	void Set_Display_Text(const QString &display_text);
	void Set_Status_Text(const QString &status_text);
	void Add_Display_Text(const QString &text);
	void Add_Status_Text(const QString &text);

// NOT IMPLEMENTED
	TPCDMonitorRemote(const TPCDMonitorRemote&);
	TPCDMonitorRemote& operator=(const TPCDMonitorRemote&);
};

#endif
